Class: Aws::PaymentCryptographyData::Types::GenerateAuthRequestCryptogramInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptographydata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:transaction_data]

Instance Attribute Summary collapse

Instance Attribute Details

#key_identifierString

The ‘keyARN` of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174

class GenerateAuthRequestCryptogramInput < Struct.new(
  :key_identifier,
  :transaction_data,
  :major_key_derivation_mode,
  :session_key_derivation_attributes)
  SENSITIVE = [:transaction_data]
  include Aws::Structure
end

#major_key_derivation_modeString

The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174

class GenerateAuthRequestCryptogramInput < Struct.new(
  :key_identifier,
  :transaction_data,
  :major_key_derivation_mode,
  :session_key_derivation_attributes)
  SENSITIVE = [:transaction_data]
  include Aws::Structure
end

#session_key_derivation_attributesTypes::SessionKeyDerivation

The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.



1174
1175
1176
1177
1178
1179
1180
1181
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174

class GenerateAuthRequestCryptogramInput < Struct.new(
  :key_identifier,
  :transaction_data,
  :major_key_derivation_mode,
  :session_key_derivation_attributes)
  SENSITIVE = [:transaction_data]
  include Aws::Structure
end

#transaction_dataString

The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using VerifyAuthRequestCryptogram.

Returns:

  • (String)


1174
1175
1176
1177
1178
1179
1180
1181
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174

class GenerateAuthRequestCryptogramInput < Struct.new(
  :key_identifier,
  :transaction_data,
  :major_key_derivation_mode,
  :session_key_derivation_attributes)
  SENSITIVE = [:transaction_data]
  include Aws::Structure
end