Class: Aws::PaymentCryptographyData::Types::GenerateMacEmvPinChangeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::GenerateMacEmvPinChangeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:new_encrypted_pin_block, :message_data]
Instance Attribute Summary collapse
-
#derivation_method_attributes ⇒ Types::DerivationMethodAttributes
The attributes and data values to derive payment card specific confidentiality and integrity keys.
-
#message_data ⇒ String
The message data is the APDU command from the card reader or terminal.
-
#new_encrypted_pin_block ⇒ String
The incoming new encrypted PIN block data for offline pin change on an EMV card.
-
#new_pin_pek_identifier ⇒ String
The ‘keyARN` of the PEK protecting the incoming new encrypted PIN block.
-
#pin_block_format ⇒ String
The PIN encoding format of the incoming new encrypted PIN block as specified in ISO 9564.
-
#secure_messaging_confidentiality_key_identifier ⇒ String
The ‘keyARN` of the issuer master key (IMK-SMC) used to protect the PIN block data in the issuer script response.
-
#secure_messaging_integrity_key_identifier ⇒ String
The ‘keyARN` of the issuer master key (IMK-SMI) used to authenticate the issuer script response.
Instance Attribute Details
#derivation_method_attributes ⇒ Types::DerivationMethodAttributes
The attributes and data values to derive payment card specific confidentiality and integrity keys.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#message_data ⇒ String
The message data is the APDU command from the card reader or terminal. The target encrypted PIN block, after translation to ISO2 format, is appended to this message data to generate an issuer script response.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#new_encrypted_pin_block ⇒ String
The incoming new encrypted PIN block data for offline pin change on an EMV card.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#new_pin_pek_identifier ⇒ String
The ‘keyARN` of the PEK protecting the incoming new encrypted PIN block.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#pin_block_format ⇒ String
The PIN encoding format of the incoming new encrypted PIN block as specified in ISO 9564.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#secure_messaging_confidentiality_key_identifier ⇒ String
The ‘keyARN` of the issuer master key (IMK-SMC) used to protect the PIN block data in the issuer script response.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |
#secure_messaging_integrity_key_identifier ⇒ String
The ‘keyARN` of the issuer master key (IMK-SMI) used to authenticate the issuer script response.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1313 class GenerateMacEmvPinChangeInput < Struct.new( :new_pin_pek_identifier, :new_encrypted_pin_block, :pin_block_format, :secure_messaging_integrity_key_identifier, :secure_messaging_confidentiality_key_identifier, :message_data, :derivation_method_attributes) SENSITIVE = [:new_encrypted_pin_block, :message_data] include Aws::Structure end |