Class: Aws::PaymentCryptographyData::Types::GenerateMacEmvPinChangeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::GenerateMacEmvPinChangeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:mac, :encrypted_pin_block]
Instance Attribute Summary collapse
-
#encrypted_pin_block ⇒ String
Returns the incoming new encrpted PIN block.
-
#mac ⇒ String
Returns the mac of the issuer script containing message data and appended target encrypted pin block in ISO2 format.
-
#new_pin_pek_arn ⇒ String
Returns the ‘keyArn` of the PEK protecting the incoming new encrypted PIN block.
-
#new_pin_pek_key_check_value ⇒ String
The key check value (KCV) of the PEK uprotecting the incoming new encrypted PIN block.
-
#secure_messaging_confidentiality_key_arn ⇒ String
Returns the ‘keyArn` of the IMK-SMC used by the operation.
-
#secure_messaging_confidentiality_key_check_value ⇒ String
The key check value (KCV) of the SMC issuer master key used by the operation.
-
#secure_messaging_integrity_key_arn ⇒ String
Returns the ‘keyArn` of the IMK-SMI used by the operation.
-
#secure_messaging_integrity_key_check_value ⇒ String
The key check value (KCV) of the SMI issuer master key used by the operation.
-
#visa_amex_derivation_outputs ⇒ Types::VisaAmexDerivationOutputs
The attribute values used for Amex and Visa derivation methods.
Instance Attribute Details
#encrypted_pin_block ⇒ String
Returns the incoming new encrpted PIN block.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#mac ⇒ String
Returns the mac of the issuer script containing message data and appended target encrypted pin block in ISO2 format.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#new_pin_pek_arn ⇒ String
Returns the ‘keyArn` of the PEK protecting the incoming new encrypted PIN block.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#new_pin_pek_key_check_value ⇒ String
The key check value (KCV) of the PEK uprotecting the incoming new encrypted PIN block.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#secure_messaging_confidentiality_key_arn ⇒ String
Returns the ‘keyArn` of the IMK-SMC used by the operation.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#secure_messaging_confidentiality_key_check_value ⇒ String
The key check value (KCV) of the SMC issuer master key used by the operation.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#secure_messaging_integrity_key_arn ⇒ String
Returns the ‘keyArn` of the IMK-SMI used by the operation.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#secure_messaging_integrity_key_check_value ⇒ String
The key check value (KCV) of the SMI issuer master key used by the operation.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |
#visa_amex_derivation_outputs ⇒ Types::VisaAmexDerivationOutputs
The attribute values used for Amex and Visa derivation methods.
1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1368 class GenerateMacEmvPinChangeOutput < Struct.new( :new_pin_pek_arn, :secure_messaging_integrity_key_arn, :secure_messaging_confidentiality_key_arn, :mac, :encrypted_pin_block, :new_pin_pek_key_check_value, :secure_messaging_integrity_key_check_value, :secure_messaging_confidentiality_key_check_value, :visa_amex_derivation_outputs) SENSITIVE = [:mac, :encrypted_pin_block] include Aws::Structure end |