Class: Aws::PaymentCryptographyData::Types::IncomingDiffieHellmanTr31KeyBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::IncomingDiffieHellmanTr31KeyBlock
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Parameter information of a TR31KeyBlock wrapped using an ECDH derived key.
Constant Summary collapse
- SENSITIVE =
[:wrapped_key_block]
Instance Attribute Summary collapse
-
#certificate_authority_public_key_identifier ⇒ String
The ‘keyArn` of the certificate that signed the client’s ‘PublicKeyCertificate`.
-
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
-
#derive_key_algorithm ⇒ String
The key algorithm of the derived ECDH key.
-
#key_derivation_function ⇒ String
The key derivation function to use for deriving a key using ECDH.
-
#key_derivation_hash_algorithm ⇒ String
The hash type to use for deriving a key using ECDH.
-
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key pair.
-
#public_key_certificate ⇒ String
The client’s public key certificate in PEM format (base64 encoded) to use for ECDH key derivation.
-
#wrapped_key_block ⇒ String
The WrappedKeyBlock containing the transaction key wrapped using an ECDH dervied key.
Instance Attribute Details
#certificate_authority_public_key_identifier ⇒ String
The ‘keyArn` of the certificate that signed the client’s ‘PublicKeyCertificate`.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#derivation_data ⇒ Types::DiffieHellmanDerivationData
The shared information used when deriving a key using ECDH.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#derive_key_algorithm ⇒ String
The key algorithm of the derived ECDH key.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#key_derivation_function ⇒ String
The key derivation function to use for deriving a key using ECDH.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#key_derivation_hash_algorithm ⇒ String
The hash type to use for deriving a key using ECDH.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#private_key_identifier ⇒ String
The ‘keyARN` of the asymmetric ECC key pair.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#public_key_certificate ⇒ String
The client’s public key certificate in PEM format (base64 encoded) to use for ECDH key derivation.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |
#wrapped_key_block ⇒ String
The WrappedKeyBlock containing the transaction key wrapped using an ECDH dervied key.
1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1747 class IncomingDiffieHellmanTr31KeyBlock < Struct.new( :private_key_identifier, :certificate_authority_public_key_identifier, :public_key_certificate, :derive_key_algorithm, :key_derivation_function, :key_derivation_hash_algorithm, :derivation_data, :wrapped_key_block) SENSITIVE = [:wrapped_key_block] include Aws::Structure end |