Class: Aws::PaymentCryptographyData::Types::KekValidationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::KekValidationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Parameter information for generating a KEK validation request during node-to-node initialization.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#derive_key_algorithm ⇒ String
The key derivation algorithm to use for generating a KEK validation request.
-
#random_key_max_length ⇒ String
The maximum length of the random key to generate for a KEK validation request.
Instance Attribute Details
#derive_key_algorithm ⇒ String
The key derivation algorithm to use for generating a KEK validation request.
1812 1813 1814 1815 1816 1817 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1812 class KekValidationRequest < Struct.new( :derive_key_algorithm, :random_key_max_length) SENSITIVE = [] include Aws::Structure end |
#random_key_max_length ⇒ String
The maximum length of the random key to generate for a KEK validation request.
1812 1813 1814 1815 1816 1817 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1812 class KekValidationRequest < Struct.new( :derive_key_algorithm, :random_key_max_length) SENSITIVE = [] include Aws::Structure end |