Class: Aws::PaymentCryptographyData::Types::MacAlgorithmDukpt
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::MacAlgorithmDukpt
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Parameters required for DUKPT MAC generation and verification.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dukpt_derivation_type ⇒ String
The key type derived using DUKPT from a Base Derivation Key (BDK) and Key Serial Number (KSN).
-
#dukpt_key_variant ⇒ String
The type of use of DUKPT, which can be MAC generation, MAC verification, or both.
-
#key_serial_number ⇒ String
The unique identifier known as Key Serial Number (KSN) that comes from an encrypting device using DUKPT encryption method.
Instance Attribute Details
#dukpt_derivation_type ⇒ String
The key type derived using DUKPT from a Base Derivation Key (BDK) and Key Serial Number (KSN). This must be less than or equal to the strength of the BDK. For example, you can’t use ‘AES_128` as a derivation type for a BDK of `AES_128` or `TDES_2KEY`.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1858 class MacAlgorithmDukpt < Struct.new( :key_serial_number, :dukpt_key_variant, :dukpt_derivation_type) SENSITIVE = [] include Aws::Structure end |
#dukpt_key_variant ⇒ String
The type of use of DUKPT, which can be MAC generation, MAC verification, or both.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1858 class MacAlgorithmDukpt < Struct.new( :key_serial_number, :dukpt_key_variant, :dukpt_derivation_type) SENSITIVE = [] include Aws::Structure end |
#key_serial_number ⇒ String
The unique identifier known as Key Serial Number (KSN) that comes from an encrypting device using DUKPT encryption method. The KSN is derived from the encrypting device unique identifier and an internal transaction counter.
1858 1859 1860 1861 1862 1863 1864 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1858 class MacAlgorithmDukpt < Struct.new( :key_serial_number, :dukpt_key_variant, :dukpt_derivation_type) SENSITIVE = [] include Aws::Structure end |