Class: Aws::PaymentCryptographyData::Types::MasterCardAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::MasterCardAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Parameters to derive the confidentiality and integrity keys for a Mastercard payment card.
Constant Summary collapse
- SENSITIVE =
[:primary_account_number, :application_cryptogram]
Instance Attribute Summary collapse
-
#application_cryptogram ⇒ String
The application cryptogram for the current transaction that is provided by the terminal during transaction processing.
-
#major_key_derivation_mode ⇒ String
The method to use when deriving the master key for the payment card.
-
#pan_sequence_number ⇒ String
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN).
-
#primary_account_number ⇒ String
The Primary Account Number (PAN) of the cardholder.
Instance Attribute Details
#application_cryptogram ⇒ String
The application cryptogram for the current transaction that is provided by the terminal during transaction processing.
1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1980 class MasterCardAttributes < Struct.new( :major_key_derivation_mode, :primary_account_number, :pan_sequence_number, :application_cryptogram) SENSITIVE = [:primary_account_number, :application_cryptogram] include Aws::Structure end |
#major_key_derivation_mode ⇒ String
The method to use when deriving the master key for the payment card.
1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1980 class MasterCardAttributes < Struct.new( :major_key_derivation_mode, :primary_account_number, :pan_sequence_number, :application_cryptogram) SENSITIVE = [:primary_account_number, :application_cryptogram] include Aws::Structure end |
#pan_sequence_number ⇒ String
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN). Typically 00 is used, if no value is provided by the terminal.
1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1980 class MasterCardAttributes < Struct.new( :major_key_derivation_mode, :primary_account_number, :pan_sequence_number, :application_cryptogram) SENSITIVE = [:primary_account_number, :application_cryptogram] include Aws::Structure end |
#primary_account_number ⇒ String
The Primary Account Number (PAN) of the cardholder.
1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1980 class MasterCardAttributes < Struct.new( :major_key_derivation_mode, :primary_account_number, :pan_sequence_number, :application_cryptogram) SENSITIVE = [:primary_account_number, :application_cryptogram] include Aws::Structure end |