Class: Aws::PaymentCryptographyData::Types::OutgoingKeyMaterial

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-paymentcryptographydata/types.rb

Overview

Note:

OutgoingKeyMaterial is a union - when making an API calls you must set exactly one of the members.

Parameter information of the outgoing TR31WrappedKeyBlock containing the transaction key.

Direct Known Subclasses

Tr31KeyBlock, Unknown

Defined Under Namespace

Classes: Tr31KeyBlock, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tr_31_key_blockTypes::OutgoingTr31KeyBlock

Parameter information of the TR31WrappedKeyBlock containing the transaction key wrapped using a KEK.



2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2001

class OutgoingKeyMaterial < Struct.new(
  :tr_31_key_block,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tr31KeyBlock < OutgoingKeyMaterial; end
  class Unknown < OutgoingKeyMaterial; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2001
2002
2003
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2001

def unknown
  @unknown
end