Class: Aws::PaymentCryptographyData::Types::PinData
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::PinData
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Note:
PinData is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PinData corresponding to the set member.
Parameters that are required to generate, translate, or verify PIN data.
Direct Known Subclasses
Defined Under Namespace
Classes: PinOffset, Unknown, VerificationValue
Constant Summary collapse
- SENSITIVE =
[:pin_offset, :verification_value]
Instance Attribute Summary collapse
-
#pin_offset ⇒ String
The PIN offset value.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#verification_value ⇒ String
The unique data to identify a cardholder.
Instance Attribute Details
#pin_offset ⇒ String
The PIN offset value.
2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2044 class PinData < Struct.new( :pin_offset, :verification_value, :unknown) SENSITIVE = [:pin_offset, :verification_value] include Aws::Structure include Aws::Structure::Union class PinOffset < PinData; end class VerificationValue < PinData; end class Unknown < PinData; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2044 2045 2046 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2044 def unknown @unknown end |
#verification_value ⇒ String
The unique data to identify a cardholder. In most cases, this is the same as cardholder’s Primary Account Number (PAN). If a value is not provided, it defaults to PAN.
2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2044 class PinData < Struct.new( :pin_offset, :verification_value, :unknown) SENSITIVE = [:pin_offset, :verification_value] include Aws::Structure include Aws::Structure::Union class PinOffset < PinData; end class VerificationValue < PinData; end class Unknown < PinData; end end |