Class: Aws::PaymentCryptographyData::Types::ReEncryptDataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::ReEncryptDataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:cipher_text]
Instance Attribute Summary collapse
-
#cipher_text ⇒ String
Ciphertext to be encrypted.
-
#incoming_encryption_attributes ⇒ Types::ReEncryptionAttributes
The attributes and values for incoming ciphertext.
-
#incoming_key_identifier ⇒ String
The ‘keyARN` of the encryption key of incoming ciphertext data.
-
#incoming_wrapped_key ⇒ Types::WrappedKey
The WrappedKeyBlock containing the encryption key of incoming ciphertext data.
-
#outgoing_encryption_attributes ⇒ Types::ReEncryptionAttributes
The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
-
#outgoing_key_identifier ⇒ String
The ‘keyARN` of the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
-
#outgoing_wrapped_key ⇒ Types::WrappedKey
The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
Instance Attribute Details
#cipher_text ⇒ String
Ciphertext to be encrypted. The minimum allowed length is 16 bytes and maximum allowed length is 4096 bytes.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#incoming_encryption_attributes ⇒ Types::ReEncryptionAttributes
The attributes and values for incoming ciphertext.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#incoming_key_identifier ⇒ String
The ‘keyARN` of the encryption key of incoming ciphertext data.
When a WrappedKeyBlock is provided, this value will be the identifier to the key wrapping key. Otherwise, it is the key identifier used to perform the operation.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#incoming_wrapped_key ⇒ Types::WrappedKey
The WrappedKeyBlock containing the encryption key of incoming ciphertext data.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#outgoing_encryption_attributes ⇒ Types::ReEncryptionAttributes
The attributes and values for outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#outgoing_key_identifier ⇒ String
The ‘keyARN` of the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |
#outgoing_wrapped_key ⇒ Types::WrappedKey
The WrappedKeyBlock containing the encryption key of outgoing ciphertext data after encryption by Amazon Web Services Payment Cryptography.
2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2180 class ReEncryptDataInput < Struct.new( :incoming_key_identifier, :outgoing_key_identifier, :cipher_text, :incoming_encryption_attributes, :outgoing_encryption_attributes, :incoming_wrapped_key, :outgoing_wrapped_key) SENSITIVE = [:cipher_text] include Aws::Structure end |