Class: Aws::PaymentCryptographyData::Types::ReEncryptionAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::ReEncryptionAttributes
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Note:
ReEncryptionAttributes is a union - when making an API calls you must set exactly one of the members.
Parameters that are required to perform reencryption operation.
Defined Under Namespace
Classes: Dukpt, Symmetric, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dukpt ⇒ Types::DukptEncryptionAttributes
Parameters that are required to encrypt plaintext data using DUKPT.
-
#symmetric ⇒ Types::SymmetricEncryptionAttributes
Parameters that are required to encrypt data using symmetric keys.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#dukpt ⇒ Types::DukptEncryptionAttributes
Parameters that are required to encrypt plaintext data using DUKPT.
2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2234 class ReEncryptionAttributes < Struct.new( :symmetric, :dukpt, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Symmetric < ReEncryptionAttributes; end class Dukpt < ReEncryptionAttributes; end class Unknown < ReEncryptionAttributes; end end |
#symmetric ⇒ Types::SymmetricEncryptionAttributes
Parameters that are required to encrypt data using symmetric keys.
2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2234 class ReEncryptionAttributes < Struct.new( :symmetric, :dukpt, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Symmetric < ReEncryptionAttributes; end class Dukpt < ReEncryptionAttributes; end class Unknown < ReEncryptionAttributes; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2234 2235 2236 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2234 def unknown @unknown end |