Class: Aws::PaymentCryptographyData::Types::TranslatePinDataInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-paymentcryptographydata/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:encrypted_pin_block]

Instance Attribute Summary collapse

Instance Attribute Details

#encrypted_pin_blockString

The encrypted PIN block data that Amazon Web Services Payment Cryptography translates.

Returns:

  • (String)


2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#incoming_as_2805_attributesTypes::As2805PekDerivationAttributes

The attributes and values to use for incoming AS2805 encryption key for PIN block translation.



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#incoming_dukpt_attributesTypes::DukptDerivationAttributes

The attributes and values to use for incoming DUKPT encryption key for PIN block translation.



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#incoming_key_identifierString

The ‘keyARN` of the encryption key under which incoming PIN block data is encrypted. This key type can be PEK or BDK.

For dynamic keys, it is the ‘keyARN` of KEK of the TR-31 wrapped PEK. For ECDH, it is the `keyARN` of the asymmetric ECC key.

Returns:

  • (String)


2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#incoming_translation_attributesTypes::TranslationIsoFormats

The format of the incoming PIN block data for translation within Amazon Web Services Payment Cryptography.



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#incoming_wrapped_keyTypes::WrappedKey

The WrappedKeyBlock containing the encryption key under which incoming PIN block data is encrypted.

Returns:



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#outgoing_dukpt_attributesTypes::DukptDerivationAttributes

The attributes and values to use for outgoing DUKPT encryption key after PIN block translation.



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#outgoing_key_identifierString

The ‘keyARN` of the encryption key for encrypting outgoing PIN block data. This key type can be PEK or BDK.

For ECDH, it is the ‘keyARN` of the asymmetric ECC key.

Returns:

  • (String)


2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#outgoing_translation_attributesTypes::TranslationIsoFormats

The format of the outgoing PIN block data after translation by Amazon Web Services Payment Cryptography.



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end

#outgoing_wrapped_keyTypes::WrappedKey

The WrappedKeyBlock containing the encryption key for encrypting outgoing PIN block data.

Returns:



2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2610

class TranslatePinDataInput < Struct.new(
  :incoming_key_identifier,
  :outgoing_key_identifier,
  :incoming_translation_attributes,
  :outgoing_translation_attributes,
  :encrypted_pin_block,
  :incoming_dukpt_attributes,
  :outgoing_dukpt_attributes,
  :incoming_wrapped_key,
  :outgoing_wrapped_key,
  :incoming_as_2805_attributes)
  SENSITIVE = [:encrypted_pin_block]
  include Aws::Structure
end