Class: Aws::PaymentCryptographyData::Types::WrappedWorkingKey
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::WrappedWorkingKey
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
The parameter information of the outgoing wrapped key block.
Constant Summary collapse
- SENSITIVE =
[:wrapped_key_material]
Instance Attribute Summary collapse
-
#key_check_value ⇒ String
The key check value (KCV) of the key contained within the outgoing TR31WrappedKeyBlock.
-
#wrapped_key_material ⇒ String
The wrapped key block of the outgoing transaction key.
-
#wrapped_key_material_format ⇒ String
The key block format of the wrapped key.
Instance Attribute Details
#key_check_value ⇒ String
The key check value (KCV) of the key contained within the outgoing TR31WrappedKeyBlock.
The KCV is used to check if all parties holding a given key have the same key or to detect that a key has changed. For more information on KCV, see [KCV][1] in the *Amazon Web Services Payment Cryptography User Guide*.
[1]: docs.aws.amazon.com/payment-cryptography/latest/userguide/terminology.html#terms.kcv
3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 3240 class WrappedWorkingKey < Struct.new( :wrapped_key_material, :key_check_value, :wrapped_key_material_format) SENSITIVE = [:wrapped_key_material] include Aws::Structure end |
#wrapped_key_material ⇒ String
The wrapped key block of the outgoing transaction key.
3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 3240 class WrappedWorkingKey < Struct.new( :wrapped_key_material, :key_check_value, :wrapped_key_material_format) SENSITIVE = [:wrapped_key_material] include Aws::Structure end |
#wrapped_key_material_format ⇒ String
The key block format of the wrapped key.
3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 3240 class WrappedWorkingKey < Struct.new( :wrapped_key_material, :key_check_value, :wrapped_key_material_format) SENSITIVE = [:wrapped_key_material] include Aws::Structure end |