Class: Aws::PaymentCryptographyData::Types::GenerateAuthRequestCryptogramInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::GenerateAuthRequestCryptogramInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:transaction_data]
Instance Attribute Summary collapse
-
#key_identifier ⇒ String
The ‘keyARN` of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.
-
#major_key_derivation_mode ⇒ String
The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.
-
#session_key_derivation_attributes ⇒ Types::SessionKeyDerivation
The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.
-
#transaction_data ⇒ String
The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation.
Instance Attribute Details
#key_identifier ⇒ String
The ‘keyARN` of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.
1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174 class GenerateAuthRequestCryptogramInput < Struct.new( :key_identifier, :transaction_data, :major_key_derivation_mode, :session_key_derivation_attributes) SENSITIVE = [:transaction_data] include Aws::Structure end |
#major_key_derivation_mode ⇒ String
The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.
1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174 class GenerateAuthRequestCryptogramInput < Struct.new( :key_identifier, :transaction_data, :major_key_derivation_mode, :session_key_derivation_attributes) SENSITIVE = [:transaction_data] include Aws::Structure end |
#session_key_derivation_attributes ⇒ Types::SessionKeyDerivation
The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.
1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174 class GenerateAuthRequestCryptogramInput < Struct.new( :key_identifier, :transaction_data, :major_key_derivation_mode, :session_key_derivation_attributes) SENSITIVE = [:transaction_data] include Aws::Structure end |
#transaction_data ⇒ String
The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using VerifyAuthRequestCryptogram.
1174 1175 1176 1177 1178 1179 1180 1181 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1174 class GenerateAuthRequestCryptogramInput < Struct.new( :key_identifier, :transaction_data, :major_key_derivation_mode, :session_key_derivation_attributes) SENSITIVE = [:transaction_data] include Aws::Structure end |