Class: Aws::PaymentCryptographyData::Types::GenerateAuthRequestCryptogramOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::GenerateAuthRequestCryptogramOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:auth_request_cryptogram]
Instance Attribute Summary collapse
-
#auth_request_cryptogram ⇒ String
The Authorization Request Cryptogram (ARQC) generated by Amazon Web Services Payment Cryptography using the specified key and transaction data.
-
#key_arn ⇒ String
The ‘keyARN` of the IMK-AC that Amazon Web Services Payment Cryptography uses for ARQC generation.
-
#key_check_value ⇒ String
The key check value (KCV) of the encryption key.
Instance Attribute Details
#auth_request_cryptogram ⇒ String
The Authorization Request Cryptogram (ARQC) generated by Amazon Web Services Payment Cryptography using the specified key and transaction data.
1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1205 class GenerateAuthRequestCryptogramOutput < Struct.new( :key_arn, :key_check_value, :auth_request_cryptogram) SENSITIVE = [:auth_request_cryptogram] include Aws::Structure end |
#key_arn ⇒ String
The ‘keyARN` of the IMK-AC that Amazon Web Services Payment Cryptography uses for ARQC generation.
1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1205 class GenerateAuthRequestCryptogramOutput < Struct.new( :key_arn, :key_check_value, :auth_request_cryptogram) SENSITIVE = [:auth_request_cryptogram] include Aws::Structure end |
#key_check_value ⇒ String
The key check value (KCV) of the encryption key. The KCV is used to check if all parties holding a given key have the same key or to detect that a key has changed.
Amazon Web Services Payment Cryptography computes the KCV according to the CMAC specification.
1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 1205 class GenerateAuthRequestCryptogramOutput < Struct.new( :key_arn, :key_check_value, :auth_request_cryptogram) SENSITIVE = [:auth_request_cryptogram] include Aws::Structure end |