Class: Aws::PaymentCryptographyData::Types::SessionKeyDerivation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PaymentCryptographyData::Types::SessionKeyDerivation
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-paymentcryptographydata/types.rb
Overview
SessionKeyDerivation is a union - when making an API calls you must set exactly one of the members.
Parameters to derive a session key for Authorization Response Cryptogram (ARQC) verification.
Defined Under Namespace
Classes: Amex, Emv2000, EmvCommon, Mastercard, Unknown, Visa
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amex ⇒ Types::SessionKeyAmex
Parameters to derive session key for an Amex payment card for ARQC verification.
-
#emv_2000 ⇒ Types::SessionKeyEmv2000
Parameters to derive session key for an Emv2000 payment card for ARQC verification.
-
#emv_common ⇒ Types::SessionKeyEmvCommon
Parameters to derive session key for an Emv common payment card for ARQC verification.
-
#mastercard ⇒ Types::SessionKeyMastercard
Parameters to derive session key for a Mastercard payment card for ARQC verification.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#visa ⇒ Types::SessionKeyVisa
Parameters to derive session key for a Visa payment cardfor ARQC verification.
Instance Attribute Details
#amex ⇒ Types::SessionKeyAmex
Parameters to derive session key for an Amex payment card for ARQC verification.
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 class SessionKeyDerivation < Struct.new( :emv_common, :mastercard, :emv_2000, :amex, :visa, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmvCommon < SessionKeyDerivation; end class Mastercard < SessionKeyDerivation; end class Emv2000 < SessionKeyDerivation; end class Amex < SessionKeyDerivation; end class Visa < SessionKeyDerivation; end class Unknown < SessionKeyDerivation; end end |
#emv_2000 ⇒ Types::SessionKeyEmv2000
Parameters to derive session key for an Emv2000 payment card for ARQC verification.
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 class SessionKeyDerivation < Struct.new( :emv_common, :mastercard, :emv_2000, :amex, :visa, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmvCommon < SessionKeyDerivation; end class Mastercard < SessionKeyDerivation; end class Emv2000 < SessionKeyDerivation; end class Amex < SessionKeyDerivation; end class Visa < SessionKeyDerivation; end class Unknown < SessionKeyDerivation; end end |
#emv_common ⇒ Types::SessionKeyEmvCommon
Parameters to derive session key for an Emv common payment card for ARQC verification.
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 class SessionKeyDerivation < Struct.new( :emv_common, :mastercard, :emv_2000, :amex, :visa, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmvCommon < SessionKeyDerivation; end class Mastercard < SessionKeyDerivation; end class Emv2000 < SessionKeyDerivation; end class Amex < SessionKeyDerivation; end class Visa < SessionKeyDerivation; end class Unknown < SessionKeyDerivation; end end |
#mastercard ⇒ Types::SessionKeyMastercard
Parameters to derive session key for a Mastercard payment card for ARQC verification.
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 class SessionKeyDerivation < Struct.new( :emv_common, :mastercard, :emv_2000, :amex, :visa, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmvCommon < SessionKeyDerivation; end class Mastercard < SessionKeyDerivation; end class Emv2000 < SessionKeyDerivation; end class Amex < SessionKeyDerivation; end class Visa < SessionKeyDerivation; end class Unknown < SessionKeyDerivation; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2315 2316 2317 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 def unknown @unknown end |
#visa ⇒ Types::SessionKeyVisa
Parameters to derive session key for a Visa payment cardfor ARQC verification.
2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-paymentcryptographydata/types.rb', line 2315 class SessionKeyDerivation < Struct.new( :emv_common, :mastercard, :emv_2000, :amex, :visa, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmvCommon < SessionKeyDerivation; end class Mastercard < SessionKeyDerivation; end class Emv2000 < SessionKeyDerivation; end class Amex < SessionKeyDerivation; end class Visa < SessionKeyDerivation; end class Unknown < SessionKeyDerivation; end end |